# Decimal Binary Converter 
A simple PYthon package to convert decimal numbers to binary and vice versa.


# Installation 
pip install dec2bin-converter

> from dec2bin-converter import decimal_to_binary, binary_to_decimal


##
> print(decimal_to_binary(10))
### output: '1010'


##
> print(binary_to_decimal(1010))
### output: 10